% La fonction "centrale_naif" évalue la probabilité quotidienne que
% survienne un accident, par une méthode de Monte-Carlo naïve. "Nsim" est
% le nombre de simulations demandées. Je ne commente que les parties non
% transparentes du code.
function centrale_naif (Nsim)
% Je donne aux variables "m", "C" et "R" une portée globale, afin de pouvoir
% aussi les utiliser dans la fonction "simuler_XYZ".
global m C R;
m = [-3 -4 -5];
C = [1, .1, .2; .1, 1, .3; .2, .3, 1];
R = chol(C);
Nacc = 0;
for i = 1:Nsim
    XYZ = m + randn (1, 3) * R;
    accident = all (XYZ >= 0);
    Nacc = Nacc + accident;
end
p = Nacc / Nsim;
% Notez qu'ici on n'a pas eu besoin de créer une variable pour la somme des
% carrés des réalisations, car celle-ci est directement égale au nombre
% d'accidents, ce qui donne directement la variance (estimée) de notre
% variable de Bernoulli à partir de p.
variance_f = p - p * p;
ect_estr = sqrt (variance_f / Nsim);
fprintf ('La probabilité d''accident est estimée à ');
fprintf ('%e ± %e.\n', p, 1.96 * ect_estr);
fprintf ('(Note : Intervalle de confiance standard à 1,96 sigmas).\n');
return
end
