% La fonction "keno_IC" estime l'espérance de gain d'un joueur de Keno par
% la méthode de Monte-Carlo, en donnant un intervalle de confiance. Nous ne
% commentons que les différences par rapport à "keno_simple"
function keno_IC ()
Nsim = 1000000;
Ncoch = 16;
total = 0;
% Pour calculer l'intervalle de confiance on a aussi besoin de calculer le
% total des carrés des quantités simulées.
total_carres = 0;
for i = 1 : Nsim
    carton = 1 : Ncoch;
    % "legain" est le gain obtenu par le joueur. Comme on va l'utiliser
    % deux fois, on doit le stocker dans une variable d'abord.
    legain = gain (score (carton, tirage ()));
    total = total + legain;
    % On met aussi à jour "total_carres".
    total_carres = total_carres + legain * legain;
end
moyenne = total / Nsim;
% On détermine aussi la variance (estimée) du gain.
variance_gain = total_carres / Nsim - moyenne * moyenne;
% On en déduit l'écart-type (estimé) de la moyenne empirique
ect_estimtr = sqrt (variance_gain / Nsim);
% On calcule les coefficients pour l'intervalle de confiance — noter qu'on
% peut aussi faire cette étape au préalable et juste entrer les résultats
% numériquement; en l'occurrence c0 vaut -1.65 et c1 vaut +3.10.
c0 = sqrt (2) * erfinv (-.90);
c1 = sqrt (2) * erfinv (+.998);
% On affiche le résultat.
fprintf ('Avec un risque de 1 ‰ pour la sous-estimation, ')
fprintf ('resp. de 5 %% pour la surestimation,\n');
fprintf ('l''espérance de gain du Keno se situe dans l''intervalle ');
fprintf ('[%f, %f] €.\n', moyenne + c0 *ect_estimtr, ...
    moyenne + c1 * ect_estimtr);
return
end
