% La fonction "calculDeC" calcule, par la méthode de Newton, la constante
% "c", solution imaginaire positive de l'équation « z³+2z²+z+1=0 ».
function c = calculDeC ()
% On initialise "c" près de la bonne valeur.
c = -.1 + .7i;
% erreur_anc est l'ancienne valeur de l'erreur commise, initialisée à
% l'infini.
erreur_anc = +Inf;
while true
    % "P" est la valeur du polynôme au point c.
    P = c * c * c + 2 * c * c + c + 1;
    % "erreur" l'erreur commise, à savoir la valeur absolue de "P", qu'il
    % s'agit de rendre nulle.
    erreur = abs (P);
    % On n'est pas sûr que l'erreur va arriver à exactement zéro ; c'est
    % pourquoi il faut prévoir une sortie de la boucle dès que l'erreur ne
    % décroit plus.
    if (erreur >= erreur_anc)
        break;
    end
    % On prépare la future valeur de "erreur_anc".
    erreur_anc = erreur;
    % "Pp" est la dérivée du polynôme en c.
    Pp = 3 * c * c + 4 * c + 1;
    % Itération de la méthode de Newton.
    c = c - P / Pp;
end
return
end
